import type { NextPage } from "next";
import dynamic from "next/dynamic";
import Link from "next/link";
import { ExpressionSetInfo, Page } from "../../components";
import {
  useExpressionSet,
  useExpressionSetQueryId,
  useExpressionsInSet,
} from "../../hooks";
import { ErrorView, ExpressionSetDetailsView } from "../../views";

function pageTitle(name?: string) {
  return `Flash Card App - ${name || "Sets"}`;
}

const ExpressionSetDetailsPage: NextPage = () => {
  const expression_set_id = useExpressionSetQueryId();
  const expression_set = useExpressionSet(expression_set_id);
  const expressions = useExpressionsInSet(expression_set_id);

  // Fallback for expression set not found
  if (!expressions) return null;
  if (!expression_set) {
    return <ErrorView title={pageTitle()} message="Expression set not found" />;
  }

  // Fallback for expression set empty
  return (
    <Page title={pageTitle(expression_set.name)}>
      <ExpressionSetDetailsView
        expression_set={expression_set}
        expression_count={expressions.length}
      />
    </Page>
  );
};

export default dynamic(() => Promise.resolve(ExpressionSetDetailsPage), {
  ssr: false,
});
