import { NextPage } from "next";
import dynamic from "next/dynamic";
import { Page } from "../../components";
import {
  useExpressionFilterQueryIds,
  useExpressionSetQueryId,
  useExpressionsInSet,
} from "../../hooks";
import { ErrorView } from "../../views";
import { ExpressionPracticeView } from "../../views";

const PageTitle = "Flash Card App - Practice";

const ExpressionPracticePage: NextPage = () => {
  const expression_set_id = useExpressionSetQueryId();
  const filter_ids = useExpressionFilterQueryIds();
  const expressions = useExpressionsInSet(expression_set_id);

  // Fallback rendering for content not yet fetched
  if (!expressions) return null;
  if (!filter_ids) return null;

  // Fallback views for expression set content not found
  if (!expression_set_id) {
    return <ErrorView title={PageTitle} message="Expression set not found" />;
  }
  const filtered_expressions = expressions.filter(
    (expression) => !filter_ids.includes(expression.id!)
  );
  if (!filtered_expressions.length) {
    return (
      <ErrorView title={PageTitle} message="No expressions left in this set" />
    );
  }

  return (
    <Page title={PageTitle}>
      <ExpressionPracticeView select_from_expressions={filtered_expressions} />
    </Page>
  );
};

export default dynamic(() => Promise.resolve(ExpressionPracticePage), {
  ssr: false,
});
