import Link from "next/link";
import { ExpressionSetInfo } from "../../components";
import { IndexedExpressionSet } from "../../model";

export interface ExpressionSetDetailsViewProps {
  expression_set: IndexedExpressionSet;
  expression_count: number;
}

export function ExpressionSetDetailsView({
  expression_set,
  expression_count,
}: ExpressionSetDetailsViewProps) {
  if (!expression_count) {
    return (
      <div className="page-with-padding scroll">
        <ExpressionSetInfo
          id={expression_set.id!}
          name={expression_set.name}
          description={expression_set.description}
          expression_count={expression_count}
        />
        <p className="text-details">No expressions left in this set.</p>
      </div>
    );
  }

  return (
    <div className="page-with-bottom-navigation">
      <section className="padding-small scroll">
        <ExpressionSetInfo
          id={expression_set.id!}
          name={expression_set.name}
          description={expression_set.description}
          expression_count={expression_count}
        />
      </section>
      <section className="navigation-bottom">
        <Link
          href={{
            pathname: "/expression-sets/practice",
            query: { "set-id": expression_set.id },
          }}
          passHref
        >
          <a className="navigation-item bottom text-navigation grow">
            <span>Practice this set</span>
          </a>
        </Link>
      </section>
    </div>
  );
}
